<?php

	class IDEALCHECKOUT_FOR_MAGENTO_2_0_7
	{
		// Return the software name
		public static function getSoftwareName()
		{
			return 'Magento 2.0.7+';
		}



		// Return the software code
		public static function getSoftwareCode()
		{
			return str_replace('_', '-', substr(basename(__FILE__), 0, -4));
		}



		// Return path to main config file (if any)
		public static function getConfigFile()
		{
			return SOFTWARE_PATH . DS . 'app' . DS . 'etc' . DS . 'env.php';
		}



		// Return path to main cinfig file (if any)
		public static function getConfigData()
		{
			$sConfigFile = self::getConfigFile();
			
			// Detect DB settings via configuration file
			if(is_file($sConfigFile))
			{
				return include($sConfigFile);
			}

			return '';
		}



		// Find default database settings
		public static function getDatabaseSettings($aSettings)
		{
			$aSettings['db_prefix'] = 'mag_';
			$aConfigData = self::getConfigData();
			
			if(!empty($aConfigData))
			{
				$aSettings['db_host'] = self::cleanupCdata($aConfigData['db']['connection']['default']['host']);
				$aSettings['db_user'] = self::cleanupCdata($aConfigData['db']['connection']['default']['username']);
				$aSettings['db_pass'] = self::cleanupCdata($aConfigData['db']['connection']['default']['password']);
				$aSettings['db_name'] = self::cleanupCdata($aConfigData['db']['connection']['default']['dbname']);
				$aSettings['db_prefix'] = self::cleanupCdata($aConfigData['db']['table_prefix']);
				
				$aSettings['db_type'] = (version_compare(PHP_VERSION, '5.3', '>') ? 'mysqli' : 'mysql');
			}

			return $aSettings;
		}

		public static function cleanupCdata($sString)
		{
			$sString = trim($sString);

			if(strcasecmp(substr($sString, 0, 9), '<![CDATA[') === 0)
			{
				$sString = substr($sString, 9);
			}

			if(strcasecmp(substr($sString, -3), ']]>') === 0)
			{
				$sString = substr($sString, 0, -3);
			}

			$sString = str_replace(']]]]><![CDATA[>', ']]>', $sString);

			return $sString;
		}



		// See if current software == self::$sSoftwareCode
		public static function isSoftware()
		{
			$aFiles = array();
			$aFiles[] = SOFTWARE_PATH . DS . 'app/etc/env.php';
			$aFiles[] = SOFTWARE_PATH . DS . 'pub';

			foreach($aFiles as $sFile)
			{
				if(!is_file($sFile) && !is_dir($sFile))
				{
					return false;
				}
			}

			return true;
		}




		// Install plugin, return text
		public static function doInstall($aSettings)
		{
			IDEALCHECKOUT_INSTALL::doInstall($aSettings);
			return true;
		}



		// Install plugin, return text
		public static function getInstructions($aSettings)
		{
			$sHtml = '';
			$sHtml .= '<ol>';
			$sHtml .= '<li>Login via SSH en navigeer naar de root map van je Magento 2 installatie.</li>';
			$sHtml .= '<li>Voer de volgende commands uit: <br>
- php bin/magento cache:clean <br>
- php bin/magento setup:upgrade <br>
Het kan voorkomen dat je de melding krijgt: Please rerun compile command, gebruik dan de volgende: 
- php -d set_time_limit=3600 -d memory_limit=1024M bin/magento setup:di:compile
.</li>';
			$sHtml .= '<li>Log in op de beheeromgeving van uw webshop.</li>';
			$sHtml .= '<li>Ga in het hoofdmenu naar Store / Configuration, en klik vervolgens op Sales</li>';
			$sHtml .= '<li>Klik op Payment methods en configureer de iDEAL Checkout plug-in..</li>';
			$sHtml .= '<li>Schakel de iDEAL Checkout betaalmethode in (Enabled=Yes) en vul een titel in voor de betaalmethode (Title=iDEAL). Klik daarna op de "Save Config"-knop</li>';
			$sHtml .= '<li>Herhaal stap 5 voor de overige betaalmethoden die u wilt aanbieden in uw webshop.</li>';
			$sHtml .= '</ol>';

			return $sHtml;
		}
	}

?>